import { 
  select, 
  forceSimulation, 
  forceX, 
  forceY,
  forceCollide,
  forceManyBody,
  forceLink, 
  json
} from 'd3';

let prj;
const canvas = select('#network');
const width = canvas.attr('width');
const height = canvas.attr('height');
const r = 7;
const ctx = canvas.node().getContext('2d');

const simulation = forceSimulation()
  .force('x', forceX(300))
  .force('y', forceY(200))
  .force('colide', forceCollide(r + 2))
  .force('charge', forceManyBody()
    .strength(-200))
  .force('link', forceLink()
    .id(d => d.id))

function update() {
  ctx.clearRect(0, 0, width, height);

  ctx.lineWidth = 4;
  prj.relacoes.forEach(d => drawLink(d));

  ctx.beginPath();
  prj.atividades.forEach(d => drawNode(d));
  ctx.fill();
}

function drawNode(d) {
  ctx.moveTo(d.x, d.y);
  ctx.arc(d.x, d.y, r, 0, 2 * Math.PI);
}

function drawLink(d) {
  ctx.strokeStyle = 'lightblue';
  ctx.beginPath();
  ctx.moveTo(d.source.x, d.source.y);
  ctx.lineTo(d.target.x, d.target.y);
  ctx.stroke();
}

json('P10210.json').then(pj => {
  prj = pj;
  
  prj.relacoes.forEach(d => {
    d.source = d.predecessora;
    d.target = d.sucessora;
  });

  simulation
    .nodes(prj.atividades)
    .on('tick', update)
    .force('link')
    .links(prj.relacoes) 
console.log(prj);
});